==> o365-3.0.1.tar.gz: o365/modules/o365_links/src/Form/SettingsForm.php <==
<?php

namespace Drupal\o365_links\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure o365_links settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The list of office 365 applications.
   *
   * @var \string[][]
   */
  protected $officeLinks;

  /**
   * The cache tag invalidator service.
   *
   * @var \Drupal\o365_links\O365CacheInvalidator
   */
  protected $cacheInvalidator;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    $instance = parent::create($container);
    $service = $container->get('o365_links.constants');
    $instance->officeLinks = $service->getApplications();

    $cacheService = $container->get('o365_links.cache_invalidator');
    $instance->cacheInvalidator = $cacheService;

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'o365_links_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['o365_links.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#attached']['library'][] = 'o365/icons';
    $form['#attached']['library'][] = 'o365_links/backend';

    $form['new_window'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Open links in a new window'),
      '#default_value' => $this->config('o365_links.settings')
        ->get('new_window'),
    ];

    $form['applications'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Office 365 applications'),
    ];

    foreach ($this->officeLinks as $name => $value) {
      $configKey = 'o365_links_' . $name;
      $form['applications'][$configKey] = [
        '#type' => 'checkbox',
        '#title' => Markup::create('<div class="o365-link-inline ms-BrandIcon--icon48 ms-BrandIcon--' . $name . '"></div><span class="name">' . $value['label'] . '</span>'),
        '#default_value' => $this->config('o365_links.settings')
          ->get($configKey),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('o365_links.settings');
    $config->set('new_window', $form_state->getValue('new_window'));

    foreach ($this->officeLinks as $name => $value) {
      $configKey = 'o365_links_' . $name;
      $config->set($configKey, $form_state->getValue($configKey));
    }

    $config->save();
    $this->cacheInvalidator->invalidateBlockCache();
    parent::submitForm($form, $form_state);
  }

}

==> o365-5.0.8.tar.gz: o365/modules/o365_links/src/Form/SettingsForm.php <==
<?php

namespace Drupal\o365_links\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure o365_links settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The list of Office 365 applications.
   *
   * @var array
   */
  protected $officeLinks;

  /**
   * The cache tag invalidator service.
   *
   * @var \Drupal\o365_links\O365CacheInvalidator
   */
  protected $cacheInvalidator;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    $instance = parent::create($container);
    $service = $container->get('o365_links.constants');
    $instance->officeLinks = $service->getApplications();

    $cacheService = $container->get('o365_links.cache_invalidator');
    $instance->cacheInvalidator = $cacheService;

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'o365_links_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['o365_links.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#attached']['library'][] = 'o365/icons';
    $form['#attached']['library'][] = 'o365_links/backend';

    $form['new_window'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Open links in a new window'),
      '#default_value' => $this->config('o365_links.settings')
        ->get('new_window'),
    ];

    $form['applications'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Office 365 applications'),
    ];

    foreach ($this->officeLinks as $name => $value) {
      $configKey = 'o365_links_' . $name;
      $form['applications'][$configKey] = [
        '#type' => 'checkbox',
        '#title' => Markup::create('<div class="o365-link-inline ms-BrandIcon--icon48 ms-BrandIcon--' . $name . '"></div><span class="name">' . $value['label'] . '</span>'),
        '#default_value' => $this->config('o365_links.settings')
          ->get($configKey),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('o365_links.settings');
    $config->set('new_window', $form_state->getValue('new_window'));

    foreach ($this->officeLinks as $name => $value) {
      $configKey = 'o365_links_' . $name;
      $config->set($configKey, $form_state->getValue($configKey));
    }

    $config->save();
    $this->cacheInvalidator->invalidateBlockCache();
    parent::submitForm($form, $form_state);
  }

}
